.elessar-handle {
  display: block;
  background: black;
  height: 100%;
  width: 5px;
  cursor: ew-resize;
  position: absolute;
  top: auto;
  bottom: 0;
  z-index: 11;
}

.elessar-handle:first-child {
  left: 0;
}

.elessar-handle:last-child {
  right: 0;
}

.elessar-vertical .elessar-handle {
  height: 5px;
  width: 100%;
  left: 0;
  right: 0;
  top: auto;
  bottom: auto;
  cursor: ns-resize;
}

.elessar-vertical .elessar-handle:first-child {
  top: 0;
}

.elessar-vertical .elessar-handle:last-child {
  bottom: 0;
}

.elessar-indicator {
  position: absolute;
  background: black;
  border-color: white;
  border-style: solid;
  border-width: 0 1px;
  width: 2px;
  height: 100%;
  z-index: 15;
}

.elessar-vertical .elessar-indicator {
  width: 100%;
  height: 2px;
}

.elessar-range {
  position: absolute;
  cursor: pointer;
  cursor: -webkit-grab;
  cursor: -moz-grab;
  cursor: grab;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  background: blue;
  width: 0;
  z-index: 10;
}

.elessar-vertical .elessar-range {
  width: auto;
  height: 0;
}

.elessar-label {
  position: absolute;
  z-index: 5;
  pointer-events: none;
  border-left: 1px solid #999;
  padding-left: 10px;
}

.elessar-readonly {
  opacity: 0.6;
  cursor: default !important;
}

.elessar-phantom {
  background-color: transparent;
  background: rgba(0, 0, 0, 0.5);
  color: white;
  cursor: pointer !important;
}

body .elessar-rangebar {
  position: relative;
  height: 26px;
  line-height: 26px;
  background: #fff !important;
  -webkit-touch-callout: none;
  -webkit-user-select: none;
  -khtml-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
  overflow: visible;
  margin-bottom: 0;
  border-radius: 0;
}

.elessar-delete-confirm {
  background: red;
}

body.elessar-resizing, body.elessar-dragging {
  -webkit-touch-callout: none;
  -webkit-user-select: none;
  -khtml-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
}

body.elessar-resizing, body.elessar-resizing .bar, body.elessar-resizing .handle {
  cursor: ew-resize !important;
}

body.elessar-resizing.elessar-resizing-vertical, body.elessar-resizing.elessar-resizing-vertical .bar, body.elessar-resizing.elessar-resizing-vertical .handle {
  cursor: ns-resize !important;
}

body.elessar-dragging, body.elessar-dragging .bar, body.elessar-dragging .handle {
  cursor: move !important;
  cursor: -webkit-grabbing !important;
  cursor: -moz-grabbing !important;
  cursor: grabbing !important;
}

.graphSpace {
  position: relative;
  width: 100%;
  height: 100px;
  background-color: #ffffff;
  display: block;
  box-sizing: border-box;
}

.oosComponent {
  border: 1px solid #c6cbd2;
  margin-bottom: 20px;
}

.graph-hidden .graphSpace {
  display: none;
}

.graph-hidden .elessar-range.bar {
  overflow: hidden;
}

.elessar-range.bar {
  width: 0%;
  height: 100%;
  color: #555555;
  float: left;
  font-size: 12px;
  text-align: center;
  background-color: #0e90d2;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  -webkit-transition: width 0.6s ease;
  -moz-transition: width 0.6s ease;
  -o-transition: width 0.6s ease;
  transition: width 0.6s ease;
  overflow: visible;
}

.elessar-range .removeRange {
  font-family: "Open Sans", Arial, Helvetica, Sans-Serif;
  /*font-family: sans-serif;*/
  /*
  border-radius: 50%;
  border: 1px solid #ffffff;
  background-color: #dd0000;
  */
  font-size: 25px;
  width: 20px;
  height: 20px;
  line-height: 17px;
  cursor: pointer;
  display: inline-block;
  vertical-align: middle;
  color: #ffffff;
}

.elessar-range .graphRange {
  position: absolute;
  background-color: red;
  left: 0;
  width: 100%;
  z-index: 10;
  opacity: 0.2;
}

.elessar-handle {
  opacity: 0.1;
}

.elessar-range.bar.isv {
  background-color: #cedce5;
}

.elessar-range.bar.oos {
  background-color: #d0e5ce;
}

.elessar-range.bar.notrade {
  background-color: #cccccc;
}
.pretty-split-pane-frame {
	box-sizing: border-box;
	width: 100%;
	height: 100%;
	padding: 5px;
	background: silver;
}

.pretty-split-pane-frame .split-pane > .split-pane-divider.dragged.touch {
	background: blue;
	opacity: 0.25;
}

.pretty-split-pane-component-inner {
	box-sizing: border-box;
	border: 1px solid gray;
	background: white;
	width: 100%;
	height: 100%;
	padding: 0 1em;
	overflow: auto;
}

/*!

Split Pane v0.8.0

Copyright (c) 2014 Simon Hagström

Released under the MIT license
https://raw.github.com/shagstrom/split-pane/master/LICENSE

*/
.split-pane {
	position: relative;
	height: 100%;
	width: 100%;
	overflow: hidden;
}

.split-pane.fixed-top > .split-pane-component,
.split-pane.fixed-bottom > .split-pane-component,
.split-pane.horizontal-percent > .split-pane-component {
	position: absolute;
	left: 0;
	width: 100%;
	overflow: auto;
	top: auto;
	bottom: 0;
	z-index: 1;
}

.split-pane.fixed-top > .split-pane-component:first-child,
.split-pane.fixed-bottom > .split-pane-component:first-child,
.split-pane.horizontal-percent > .split-pane-component:first-child {
	top: 0;
	bottom: auto;
}

.split-pane.fixed-top > .split-pane-divider,
.split-pane.fixed-bottom > .split-pane-divider,
.split-pane.horizontal-percent > .split-pane-divider {
	position: absolute;
	width: 100%;
	left: 0;
	cursor: row-resize;
	z-index: 2;
}

.split-pane.fixed-top > .split-pane-divider > .split-pane-divider-inner,
.split-pane.fixed-bottom > .split-pane-divider > .split-pane-divider-inner,
.split-pane.horizontal-percent > .split-pane-divider > .split-pane-divider-inner {
	position: absolute;
	top: -5px;
	left: 0;
	box-sizing: content-box;
	width: 100%;
	height: 100%;
	padding: 5px 0;
}

.split-pane.fixed-left > .split-pane-component,
.split-pane.fixed-right > .split-pane-component,
.split-pane.vertical-percent > .split-pane-component {
	position: absolute;
	top: 0;
	height: 100%;
	overflow: auto;
	left: auto;
	right: 0;
	z-index: 1;
}

.split-pane.fixed-left > .split-pane-component:first-child,
.split-pane.fixed-right > .split-pane-component:first-child,
.split-pane.vertical-percent > .split-pane-component:first-child {
	left: 0;
	right: auto;
}

.split-pane.fixed-left > .split-pane-divider,
.split-pane.fixed-right > .split-pane-divider,
.split-pane.vertical-percent > .split-pane-divider {
	position: absolute;
	height: 100%;
	top: 0;
	cursor: col-resize;
	z-index: 2;
}

.split-pane.fixed-left > .split-pane-divider > .split-pane-divider-inner,
.split-pane.fixed-right > .split-pane-divider > .split-pane-divider-inner,
.split-pane.vertical-percent > .split-pane-divider > .split-pane-divider-inner {
	position: absolute;
	top: 0;
	left: -5px;
	box-sizing: content-box;
	width: 100%;
	height: 100%;
	padding: 0 5px;
}

.split-pane-resize-shim {
	position: absolute;
	top: 0;
	left: 0;
	width: 100%;
	height: 100%;
	z-index: 10000;
	display: none;
}

.split-pane.fixed-left > .split-pane-resize-shim,
.split-pane.fixed-right > .split-pane-resize-shim,
.split-pane.vertical-percent > .split-pane-resize-shim {
	cursor: col-resize;
}

.split-pane.fixed-top > .split-pane-resize-shim,
.split-pane.fixed-bottom > .split-pane-resize-shim,
.split-pane.horizontal-percent > .split-pane-resize-shim {
	cursor: row-resize;
}

.slider-container {
  width: 300px;
  max-width: 100%;
  margin-bottom: 10px;
  margin-top: 8px;
  font-family: "Helvetica Neue", Helvetica, Arial, sans-serif;
}
.slider-container .back-bar {
  height: 10px;
  position: relative;
}
.slider-container .back-bar .selected-bar {
  position: absolute;
  height: 100%;
}
.slider-container .back-bar .pointer {
  position: absolute;
  width: 10px;
  height: 10px;
  background-color: red;
  cursor: col-resize;
  opacity: 1;
  z-index: 2;
}
.slider-container .back-bar .pointer.last-active {
  z-index: 3;
}
.slider-container .back-bar .pointer-label {
  position: absolute;
  top: -17px;
  font-size: 8px;
  background: white;
  white-space: nowrap;
  line-height: 1;
}
.slider-container .back-bar .focused {
  z-index: 10;
}
.slider-container .clickable-dummy {
  cursor: pointer;
  position: absolute;
  width: 100%;
  height: 100%;
  z-index: 1;
}
.slider-container .scale {
  top: 2px;
  position: relative;
}
.slider-container .scale span {
  position: absolute;
  height: 5px;
  border-left: 1px solid #999;
  font-size: 0;
}
.slider-container .scale ins {
  font-size: 9px;
  text-decoration: none;
  position: absolute;
  left: 0;
  top: 5px;
  color: #999;
  line-height: 1;
}
.slider-container.slider-readonly .clickable-dummy,
.slider-container.slider-readonly .pointer {
  cursor: auto;
}
.theme-green .back-bar {
  height: 5px;
  border-radius: 2px;
  background-color: #eeeeee;
  background-color: #e7e7e7;
  background-image: -moz-linear-gradient(top, #eeeeee, #dddddd);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#eeeeee), to(#dddddd));
  background-image: -webkit-linear-gradient(top, #eeeeee, #dddddd);
  background-image: -o-linear-gradient(top, #eeeeee, #dddddd);
  background-image: linear-gradient(to bottom, #eeeeee, #dddddd);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffeeeeee', endColorstr='#ffdddddd', GradientType=0);
}
.theme-green .back-bar .selected-bar {
  border-radius: 2px;
  background: rgba(73,155,234,1);
  background: -moz-linear-gradient(top, rgba(73,155,234,1) 0%, rgba(32,124,229,1) 100%);
  background: -webkit-gradient(left top, left bottom, color-stop(0%, rgba(73,155,234,1)), color-stop(100%, rgba(32,124,229,1)));
  background: -webkit-linear-gradient(top, rgba(73,155,234,1) 0%, rgba(32,124,229,1) 100%);
  background: -o-linear-gradient(top, rgba(73,155,234,1) 0%, rgba(32,124,229,1) 100%);
  background: -ms-linear-gradient(top, rgba(73,155,234,1) 0%, rgba(32,124,229,1) 100%);
  background: linear-gradient(to bottom, rgba(73,155,234,1) 0%, rgba(32,124,229,1) 100%);
  filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#499bea', endColorstr='#207ce5', GradientType=0 );
}
.theme-green .back-bar .pointer {
  width: 14px;
  height: 14px;
  top: -5px;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  border-radius: 10px;
  border: 1px solid #AAA;
  background-color: #e7e7e7;
  background-image: -moz-linear-gradient(top, #eeeeee, #dddddd);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#eeeeee), to(#dddddd));
  background-image: -webkit-linear-gradient(top, #eeeeee, #dddddd);
  background-image: -o-linear-gradient(top, #eeeeee, #dddddd);
  background-image: linear-gradient(to bottom, #eeeeee, #dddddd);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffeeeeee', endColorstr='#ffdddddd', GradientType=0);
}
.theme-green .back-bar .pointer-label {
  color: #999;
}
.theme-green .back-bar .focused {
  color: #333;
}
.theme-green .scale span {
  border-left: 1px solid #e5e5e5;
}
.theme-green .scale ins {
  color: #999;
}
.theme-blue .back-bar {
  height: 5px;
  border-radius: 2px;
  background-color: #eeeeee;
  background-color: #e7e7e7;
  background-image: -moz-linear-gradient(top, #eeeeee, #dddddd);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#eeeeee), to(#dddddd));
  background-image: -webkit-linear-gradient(top, #eeeeee, #dddddd);
  background-image: -o-linear-gradient(top, #eeeeee, #dddddd);
  background-image: linear-gradient(to bottom, #eeeeee, #dddddd);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffeeeeee', endColorstr='#ffdddddd', GradientType=0);
}
.theme-blue .back-bar .selected-bar {
  border-radius: 2px;
  background-color: #92c1f9;
  background-image: -moz-linear-gradient(top, #b1d1f9, #64a8f9);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#b1d1f9), to(#64a8f9));
  background-image: -webkit-linear-gradient(top, #b1d1f9, #64a8f9);
  background-image: -o-linear-gradient(top, #b1d1f9, #64a8f9);
  background-image: linear-gradient(to bottom, #b1d1f9, #64a8f9);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffb1d1f9', endColorstr='#ff64a8f9', GradientType=0);
}
.theme-blue .back-bar .pointer {
  width: 14px;
  height: 14px;
  top: -5px;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  border-radius: 10px;
  border: 1px solid #AAA;
  background-color: #e7e7e7;
  background-image: -moz-linear-gradient(top, #eeeeee, #dddddd);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#eeeeee), to(#dddddd));
  background-image: -webkit-linear-gradient(top, #eeeeee, #dddddd);
  background-image: -o-linear-gradient(top, #eeeeee, #dddddd);
  background-image: linear-gradient(to bottom, #eeeeee, #dddddd);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffeeeeee', endColorstr='#ffdddddd', GradientType=0);
}
.theme-blue .back-bar .pointer-label {
  color: #999;
}
.theme-blue .back-bar .focused {
  color: #333;
}
.theme-blue .scale span {
  border-left: 1px solid #e5e5e5;
}
.theme-blue .scale ins {
  color: #999;
}

body,
html {
    -webkit-touch-callout: none;
    -webkit-user-select: none;
    -khtml-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    user-select: none;
}

* {
    box-sizing: border-box;
}

.sqn-container {
    position: absolute;
    top: 0;
    left: 0;
    right: 0;
    bottom: 0;
    overflow: hidden;
    height: auto;
    width: auto;
    background-color: #ececec;
}

.sqn-container .split-pane-component:first-child {
    margin-bottom: 0;
    margin-top: 0;
}

.sqn-dashboard {
    overflow: auto;
    background-color: #f6f6f6;
    position: absolute;
    top: 0;
    left: 0;
    bottom: 0;
    right: 0;
}

.sqn-dashboard .sqn-dasboard-flex-container {
    display: flex;
}

.sqn-container>div:first-child {
    height: 100%;
}

.sqn-container.sq-splitter#sq-splitter-main>div:first-child {
    height: auto;
}

.sqn-dashboard.settings-pane-shown {
    overflow: hidden;
}

.sqn-container.databanks-shown .split-pane-component:first-child {
    margin-bottom: 14px;
}

.sqn-dashboard.settings-pane-shown .sqn-engine {
    display: none;
}

.sqn-dashboard.settings-pane-shown .sqn-results {
    display: none;
}

.sqn-dashboard.settings-pane-shown .sqn-settings-databanks-panel {
    display: none;
}

.sqn-dashboard .sqn-dasboard-flex-container>div {
    background-color: #f6f6f6;
    border-right: 0;
    padding-top: 22px;
}

.sqn-dashboard .sqn-dasboard-flex-container>div.active.sqn-results {
    border-right: 0;
}

.sqn-title {
    font-size: 16px;
    font-weight: 400;
    color: #555555;
    padding-left: 10px;
    padding-bottom: 10px;
    position: relative;
    display: inline-block;
    max-width: 100%;
}

.sqn-title:hover {
    cursor: pointer;
    color: #555555;
    text-decoration: underline;
}

.active>.sqn-title {
    color: #555555;
    font-weight: 600;
}

.active>.sqn-title.dropdown {
    color: #555555;
    font-weight: 400;
}

.active>.sqn-title .sqn-title-beginning {
    color: #555555;
    font-weight: 600;
}

.active>.sqn-title .sqn-title-beginning:hover {
    text-decoration: none;
}

.active>.sqn-title:hover {
    text-decoration: none;
}

.sqn-title .dropdown.dropdown-settings {
    position: relative;
    display: flex;
}

.sqn-title.dropdown.dropdown-settings .dropdown-menu {
    top: 25px !important;
    left: auto;
    right: -133px;
    width: auto;
}

.sqn-title .dropdown .dropdown-submenu .dropdown-menu {
    top: 3px !important;
    left: 100%;
    margin-left: -3px;
    right: auto !important;
}

body .sqn-title .dropdown .dropdown-submenu .dropdown-menu>li>a {
    display: flex;
}

.sqn-title .dropdown .dropdown-menu-files li span {
    float: none;
    margin-right: 10px;
    margin-top: 1px;
}

.sqn-title a.sqn-settings-load-menu {
    cursor: pointer;
    text-decoration: none;
    max-width: 100%;
    color: #555555;
    font-size: 14px;
    display: block;
    width: 10px;
    height: 11px;
    margin-top: 2px;
    margin-right: 6px;
}

.sqn-settings .sqn-title {
    display: flex;
}

.sqn-settings .sqn-title .sqn-title-beginning {
    white-space: nowrap;
    flex: 1 1 auto;
}

.advanced-settings {
    text-align: center;
    display: block;
    padding-top: 12px;
    padding-bottom: 6px;
    border-top: 1px solid #c1c1c1;
}

.advanced-settings a {}

.sqn-settings .sqn-title .sqn-title-middle {
    white-space: nowrap;
    flex: 0 1 auto;
}

.sqn-settings .sqn-title .sqn-title-subtitle {
    white-space: nowrap;
    flex: 1 1 auto;
    line-height: 1.2em;
    font-size: 14px;
    padding-top: 3px;
    padding-left: 3px;
    color: #777777;
    max-width: 100%;
    white-space: nowrap;
    overflow: hidden;
    text-overflow: ellipsis;
}

.sqn-settings .sqn-title:hover {
    text-decoration: none;
    color: #777777;
}

.sqn-settings .sqn-title .sqn-title-beginning:hover {
    color: #797979;
    text-decoration: underline;
    cursor: pointer;
}

.sqn-settings.active .sqn-title .sqn-title-beginning:hover {
    text-decoration: none;
}

.sqn-results .sqn-title a.link-small {
    margin-left: 23px;
}

.split-pane-component-dashboard {
    display: flex;
    flex-direction: column;
}

.sqn-dashboard-view {
    flex: 1 0 auto;
    position: relative;
    background-color: #f6f6f6;
}

.sq-app-taskmanager .sqn-engine {
    width: 567px;
}

.sqn-hide-header .sqn-dashboard-header {
    display: none;
}

.sqn-hide-settings .sqn-dashboard-header .sqn-settings {
    display: none;
}

.sqn-dashboard-view .sqn-title {
    display: none;
}

.sqn-dashboard-view .sqn-settings-body {
    top: 0;
}

.sqn-databanks {
    min-height: 19px;
    height: 1%;
    background-color: #ffffff;
    border-bottom: 0;
    overflow: visible !important;
    right: 0 !important;
    left: 0 !important;
    width: auto !important;
    display: none;
}

.sq-splitter#sq-splitter-main .sqn-databanks {
    display: block;
    z-index: 100;
}

.databanks-shown .sqn-databanks {
    min-height: 100px;
    background-color: transparent;
    border: 0;
}

.sqn-container .split-pane-divider {
    display: none;
}

.sqn-container.databanks-shown .split-pane-divider {
    display: block;
}

.sqn-databanks-header {
    text-align: center;
    font-size: 11px;
    color: #000000;
    line-height: 19px;
    position: relative;
    z-index: 13;
    background-color: #7dbbf5;
    border-top: 1px solid #4ea2f0;
}

/*.sqn-databanks-in-taskmanager .sqn-databanks-header {
    z-index: 10;
    background-color: transparent;
    color: #727272;
}*/

.sqn-container.active .sqn-databanks-header {
    background-color: #bddefb;
    z-index: 9;
    border-top: 1px solid #a5d3f9;
    /* border-bottom: 1px solid #a5d3f9; */
    font-size: 0;
    height: 9px;
}

.databanks-shown .sqn-databanks-header {
    font-size: 0;
    line-height: 10px;
    height: 11px;
}

.sqn-databanks-opener {
    width: 31px;
    height: 11px;
    display: inline-block;
    vertical-align: -2px;
    margin: 0 10px;
}

.sqn-container.active .sqn-databanks-opener {
    width: 60px;
}

.sqn-settings {
    margin-right: 0;
    flex: 0 0 500px;
    order: 2;
    padding-left: 12px;
    padding-right: 12px;
    width: 500px;
}

.sqn-settings .settings-group legend {
    color: #207ace;
    font-size: 15px;
    border-bottom: 0;
    margin-bottom: 10px;
}

.sqn-settings .settings-group table {
    width: 100%;
    table-layout: fixed;
}

.sqn-settings .settings-group table tr {
    font-size: 12px;
}

.sqn-settings .settings-group table tr td:first-child {
    width: 138px;
    white-space: nowrap;
    text-overflow: ellipsis;
    overflow: hidden;
    padding-left: 9px;
    padding-top: 6px;
    padding-bottom: 6px;
    vertical-align: top;
    padding-right: 10px;
}

.sqn-settings .settings-group table tr td:last-child {
    padding-left: 3px;
    padding-top: 6px;
    padding-bottom: 6px;
    vertical-align: top;
}

.sq-app-taskmanager .sqn-dashboard .sqn-dasboard-flex-container {
    padding-left: 300px;
}

.sqn-tasksflow {
    width: 200px;
    order: 1;
    flex: 0 0 auto;
    position: fixed;
    top: 51px;
    left: 0;
    bottom: 19px;
    z-index: 15;
    padding-top: 0 !important;
}

.sqn-tasksflow .tm-tasks-list {
    height: 100%;
    display: flex;
    flex-direction: column;
    z-index: 10;
    height: 100%;
    position: relative;
}

.sqn-tasksflow .tm-tasks-list>div:first-child {
    flex: 1 1 auto;
    overflow: auto;
    padding: 22px 4px 22px 14px;
}

.sqn-tasksflow .tm-tasks-list>div:last-child {
    flex: 0 0 auto;
}

.sqn-tasksflow .tm-tasks-list .tm-task-box {
    border: 1px solid #cecdd5;
    padding-left: 14px;
    margin-bottom: 25px;
    background-position: 6px center;
    background-repeat: no-repeat;
    position: relative;
}

.tm-task-progressbar {
    height: 3px;
    position: absolute;
    top: 0;
    left: 0;
    right: 0;
}

.tm-task-box.task-in-progress .tm-task-progressbar {
    /* background-image: url(../../img/task-progress-animation.gif);
    background-size: 100%; */
    background: transparent;
}

.tm-task-box.task-in-progress .tm-task-progressbar>div {
    animation: progress-sq 2s linear infinite;
    background-color: #5897d4;
    width: 25%;
    height: 3px;
}

.tm-task-box.task-in-progress.task-selected .tm-task-progressbar {
    background-color: #5897d4;
}

.tm-task-box.task-in-progress.task-selected .tm-task-progressbar>div {
    animation: progress-sq 2s linear infinite;
    background-color: #ffffff;
    width: 25%;
    height: 3px;
}

.tm-task-box.task-finished .tm-task-progressbar {
    background-color: #44a048;
}

.tm-task-box.task-selected .tm-task-progressbar,
.tm-task-box.task-finished.task-selected .tm-task-progressbar {
    background-color: #5897d4;
}

.sqn-tasksflow .tm-tasks-list .tm-task-box:after {
    top: 43px;
    background-image: url(../../img/tm-task-arr-bottom-white.png);
}

.sqn-tasksflow .tm-tasks-list .tm-task-box:last-of-type:after {
    background: none;
}

.tm-tasks-list .tm-task-box.task-selected:before {
    content: '';
    display: block;
    background-color: #5897d4;
    position: absolute;
    top: 0;
    left: 0;
    right: 0;
    height: 3px;
}

.tm-tasks-list .tm-task-box.task-selected:hover:before {
    opacity: 0.8;
}

.sqn-engine {
    flex: 0 0 auto;
    width: 556px;
    order: 1;
    padding-right: 12px;
    padding-left: 12px;
}

.sqn-results {
    width: 318px;
    flex: 1 1 auto;
    padding-left: 12px;
    padding-right: 12px;
    order: 3;
}

.sqn-engine .engine-container-stats {
    width: auto;
    margin-right: 0;
}

.sqn-engine .engine-project-stats tr td {
    padding: 0 4px;
    position: relative;
}

.sqn-engine .engine-project-stats tr td:first-child {
    padding-right: 12px;
}

.sqn-engine .engine-project-stats tr td:last-child {
    padding-left: 12px;
}

.sqn-engine .log-buttons {
    margin-top: 0;
    margin-bottom: 0;
    color: #555555;
    position: relative;
    top: 5px;
}

.sqn-engine .engine-project-log-inner {
    display: block;
    position: static;
    margin-bottom: 10px;
}

.sqn-engine .log-scroll-content {
    position: static;
    white-space: pre;
    color: #555555;
    font-size: 11px;
    line-height: 16px;
    min-height: 207px;
}

.sqn-engine .engine-container-instances {
    overflow: visible;
    display: flex;
    margin: 0 -5px;
}

.sqn-engine .engine-chart-panel {
    min-height: 249px;
    height: auto;
    width: auto;
    display: block;
    float: none;
    background-color: #ffffff;
    border: 0;
    border-radius: 0;
    box-shadow: 0 1px 3px rgba(0, 0, 0, .12), 0 1px 2px rgba(0, 0, 0, .24);
    -webkit-transition: all 120ms cubic-bezier(.4, 0, .2, 1);
    transition: all 120ms cubic-bezier(.4, 0, .2, 1);
    will-change: box-shadow;
    overflow: hidden;
}

.sqn-engine .engine-chart-panel .sq-input {
    margin-right: 0;
}

.sqn-engine .engine-chart-panel img {
    width: 100%;
}

.sqn-engine .engine-chart-panel .sq-input-select-overlay {
    border-color: transparent;
    background-image: url(../../../img/sq-select-white.png);
    background-color: #ffffff;
    text-align: center;
}

.sqn-engine .engine-chart-panel .sq-input:hover .sq-input-select-overlay {
    border-color: #c1c1c1;
    background-position: right center;
}

.sqn-tabbutton {
    display: block;
    height: 50px;
    border-bottom: 1px solid #dddddd;
    cursor: pointer;
    background: transparent;
    padding: 9px 14px;
    color: #0074bd;
    font-size: 13px;
    font-weight: 500;
    overflow: visible;
}

.sqn-tabbutton span {
    display: block;
    font-weight: 400;
    color: #999999;
    font-size: 12px;
    line-height: 30px;
    height: 30px;
    margin-top: -5px;
    overflow: hidden;
}

.sqn-tabbutton:last-child {
    margin-bottom: 0;
    border-bottom: 0;
}

.sqn-tabbutton:hover {
    z-index: 10;
}

.sqn-tabbutton.active,
.sqn-tabbutton:hover {
    background: #ffffff;
    box-shadow: 0 10px 20px rgba(0, 0, 0, .19), 0 6px 6px rgba(0, 0, 0, .23);
}

.sqn-tabbutton.active {
    position: relative;
    z-index: 12;
    border-right: 0;
    box-shadow: 0 10px 20px rgba(0, 0, 0, .19), 0 6px 6px rgba(0, 0, 0, .23);
    border-left: 0;
}

.sqn-tabbutton.active:first-child {
    border-top: 0;
}

.sqn-tabbutton.error {
    position: relative;
    border-left: 0;
}

.sqn-tabbutton.error:after {
    content: '';
    display: block;
    position: absolute;
    top: -1px;
    bottom: -1px;
    left: 0;
    background-color: #c60000;
    z-index: 11;
    width: 7px;
}

.sqn-tabbutton.error span {
    color: #c60000;
}

.sqn-settings-body {
    position: absolute;
    top: 32px;
    left: 268px;
    right: 12px;
    border: 0;
    background-color: #ffffff;
    display: none;
    z-index: 8;
    flex-direction: column;
    box-shadow: 0 10px 20px rgba(0, 0, 0, .19), 0 6px 6px rgba(0, 0, 0, .23);
    overflow: auto;
    bottom: 10px;
    min-height: auto !important;
}

.sqn-settings-white-bordersh {
    display: none;
    position: absolute;
    top: 0;
    left: 268px;
    bottom: 10px;
    width: 10px;
    background-color: #ffffff;
    z-index: 15;
}

.sqn-settings-tabs {
    margin-right: -12px;
}

.sqn-settings-headln {
    display: none;
    position: absolute;
    top: 28px;
    left: 254px;
    height: 1px;
    background-color: #e1e1e1;
    z-index: 16;
}

.settings-pane-shown .sqn-settings-white-bordersh,
.settings-pane-shown .sqn-settings-headln {
    display: block;
}

.sqn-settings-closebtn {
    position: absolute;
    top: 8px;
    right: 16px;
    cursor: pointer;
    background-image: url(../../img/sq-newdes-settings-close.png);
    width: 12px;
    height: 13px;
}

.sqn-settings-body .sqn-settings-body-content {
    display: none;
    flex: 1 1 auto;
    overflow: auto;
    padding-top: 0;
    margin-top: 0;
    flex-direction: column;
}

.sqn-settings-body .sqn-settings-body-header {
    width: 100;
    height: 29px;
    line-height: 29px;
    color: #777777;
    padding-left: 22px;
    font-size: 13px;
    font-weight: 600;
    position: relative;
    border-bottom: 1px solid #c1c1c1;
    z-index: 15;
}

.sqn-settings-body .sqn-settings-body-inner {
    flex: 1 1 auto;
    overflow: auto;
    padding: 17px;
    position: relative;
}

.sqn-settings-body .sqn-settings-body-content .disable-area {
    position: absolute;
    z-index: 1000;
    width: 95%;
    height: 100%;
    cursor: not-allowed;
}

.sqn-settings-body .sqn-settings-body-content .disable-area>i {
    position: absolute;
    right: 0px;
    font-size: 30px;
}

.sqn-settings-body .sqn-settings-body-content.active {
    display: flex;
    position: relative;
}

.sqn-settings-body .sqn-settings-body-content.active:after {
    content: '';
    display: block;
    clear: both;
}

.sqn-settings-body .sqn-settings-nextbtns {
    padding: 8px 13px;
    text-align: center;
    max-width: 980px;
}

.sqn-settings-body .sqn-settings-nextbtns .btn-primary {
    width: 150px;
}

.sqn-settings-databanks-panel {
    order: 2;
}

.sqn-settings-databanks-panel .sq-input {
    margin-left: 11px;
}

.sqn-engine .project-control-panel {
    position: static;
    background-color: #ffffff;
    border: 0;
}

.sqn-engine .project-control-panel .progress {
    position: static;
    top: 40px;
    right: 30%;
    z-index: 6;
    -webkit-transition: top 0.2s ease-in-out;
    -moz-transition: top 0.2s ease-in-out;
    -o-transition: top 0.2s ease-in-out;
    -ms-transition: top 0.2s ease-in-out;
    transition: top 0.2s ease-in-out;
    -webkit-transition: right 0.2s ease-in-out;
    -moz-transition: right 0.2s ease-in-out;
    -o-transition: right 0.2s ease-in-out;
    -ms-transition: right 0.2s ease-in-out;
    transition: right 0.2s ease-in-out;
}

.sqn-engine .project-control-panel>label {
    display: none;
}

.sqn-engine .project-control-panel .progress {
    float: none;
    width: 100%;
    margin: 0;
    border-radius: 0;
    box-shadow: none;
}

body .sqn-engine .btn.sq-btn-process {
    float: none;
    display: inline-block;
}

.engine-project-log-inner {
    background-color: #ffffff;
    border: 0;
    position: relative;
    box-shadow: 0 1px 3px rgba(0, 0, 0, .12), 0 1px 2px rgba(0, 0, 0, .24);
    -webkit-transition: all 120ms cubic-bezier(.4, 0, .2, 1);
    transition: all 120ms cubic-bezier(.4, 0, .2, 1);
    will-change: box-shadow;
    padding: 12px;
}

.engine-project-log-inner .engine-project-stats {
    margin-bottom: 10px;
}

.log-scroll-content {
    height: 198px;
    padding: 5px;
    overflow-y: scroll;
    font-size: 11px;
    background-color: #ffffff;
}

.log-buttons {
    line-height: 24px;
    margin-top: 10px;
    font-size: 11px;
    color: #727272;
    margin-bottom: 10px;
}

.log-buttons button {
    margin-right: 15px;
    width: 150px;
}

.log-buttons input {
    margin-left: 10px;
    margin-top: 0;
    vertical-align: -3px;
}

.project-stats {
    background-color: #f1f1f1;
    border: 1px solid #d4d4d4;
    padding: 10px;
    flex: 0 1 auto;
    line-height: 17px;
}

.project-stats h3 {
    margin: -2px 0 16px 0;
    font-size: 13px;
    font-weight: 700;
}

.engine-container {
    display: flex;
    padding: 6px 10px 4px 10px;
    background-color: #ffffff;
    border: 1px solid #bddefb;
    border-radius: 3px;
    margin: 6px 14px 10px 14px;
}

.engine-container-stats {
    width: auto;
    display: flex;
    flex-direction: column;
}

.engine-project-stats tr td:first-child {
    width: 50%;
}

.engine-project-stats tr td {
    height: 22px;
    line-height: 22px;
    font-size: 12px;
    color: #808080;
    text-align: right;
    text-align: left;
}

.engine-project-stats tr:last-child td {
    border-bottom: 0;
}

.engine-project-log {}

.sqn-results-wrapper {
    display: flex;
    height: 100%;
}

.sqn-results-wrapper .sqn-results-col {
    flex: 1 1 auto;
    display: none;
    border: 0;
    background-color: #ffffff;
    padding: 12px;
    text-align: center;
    height: 100%;
    max-width: 350px;
    margin-left: 20px;
    cursor: pointer;
    box-shadow: 0 1px 3px rgba(0, 0, 0, .12), 0 1px 2px rgba(0, 0, 0, .24);
    -webkit-transition: all 120ms cubic-bezier(.4, 0, .2, 1);
    transition: all 120ms cubic-bezier(.4, 0, .2, 1);
    will-change: box-shadow;
}

.sqn-results-wrapper .sqn-results-col:first-child {
    display: block;
    margin-left: 0;
}

.engine-chart-box {
    display: block;
    flex: 0 1 50%;
    width: 50%;
    margin: 0 5px 10px 5px;
    margin-bottom: 10px;
}

.engine-chart-box:first-child {
    display: block;
}

.sqn-container.split-pane.horizontal-percent .split-pane-divider {
    bottom: 50%;
    height: 0;
    text-align: center;
}

.sqn-container.split-pane.horizontal-percent .split-pane-divider>div {
    background-image: url(../../img/split-divider-small.png);
    background-repeat: no-repeat;
    height: 11px;
    width: 30px;
    top: -13px;
    display: inline-block;
    padding: 0;
}

.sqn-databanks .quant-tabs {
    position: absolute;
    left: 8px;
    right: 8px;
    bottom: 8px;
    top: 13px;
    display: flex;
    flex-direction: column;
    z-index: 10;
}

.sqn-databanks .quant-tabs>.tabs-header {
    z-index: 100;
}

.sqn-databanks .quant-tabs .tabs-body {
    flex: 1 1 auto;
    position: relative;
}

.dropdown-menu-files li {
    text-align: right;
}

.dropdown-menu-files li span {
    float: left;
    color: #afafaf;
    text-transform: uppercase;
    font-size: 10px;
}

.sqn-databanks .sq-switch {
    display: none;
}

.sqn-databanks .records-number {
    display: none;
}

.sqn-databanks .sq-input-checkbox {
    display: none !important;
}

.sqn-databanks .db-views-label .sq-input {
    vertical-align: -7px !important;
}

.sqn-settings-body {
    background-color: #ffffff;
    max-width: 980px;
}

.sqn-tabbutton.active {
    background-color: #ffffff;
}

.settings-minimum-width {
    display: block;
    min-width: 650px;
}

#globalDialog .modal-body {
    padding-left: 30px;
    padding-right: 30px;
}

#globalDialog .radio label {
    font-size: 12px;
    color: #555555;
    font-weight: normal;
    vertical-align: top;
    line-height: 19px;
    padding-left: 10px;
}

#globalDialog .row {
    margin-bottom: 6px;
}

#globalDialog .sqn-label {
    margin-left: 0;
}

#globalDialog .sqn-input {
    width: auto;
}

.tabs-settings-tabs {
    position: absolute;
    top: 38px;
    left: 10px;
    bottom: 10px;
    right: 10px;
    display: flex;
    flex-direction: column;
}

.advanced-settings-window-title {
    margin-left: 14px;
    margin-top: 11px;
}

.tabs-settings-tabs>.tabs-body {
    flex: 1 1 auto;
    position: relative;
    overflow: auto;
}

.tabs-settings-tabs>.tabs-body>div.active {
    position: absolute !important;
    top: 0;
    left: 0;
    right: 0;
    bottom: 0;
    display: flex !important;
    flex-direction: column;
}

.modal .modal-body {
    display: flex;
    flex-direction: column;
    overflow: auto;
    color: #333333;
}

.modal-body>.quant-tabs {
    display: flex;
    flex-direction: column;
    height: 100%;
}

.modal-body>.quant-tabs>.tabs-body {
    flex: 1 1 auto;
    overflow: auto;
}

.zoom-09 .sqn-results-wrapper .sqn-results-col:nth-child(2),
.zoom-08 .sqn-results-wrapper .sqn-results-col:nth-child(2),
.zoom-07 .sqn-results-wrapper .sqn-results-col:nth-child(2),
.zoom-06 .sqn-results-wrapper .sqn-results-col:nth-child(2) {
    display: block;
}

.zoom-07 .sqn-results-wrapper .sqn-results-col:nth-child(3),
.zoom-06 .sqn-results-wrapper .sqn-results-col:nth-child(3) {
    display: block;
}

.zoom-12 .sqn-results,
.zoom-13 .sqn-results,
.zoom-14 .sqn-results,
.zoom-15 .sqn-results,
.zoom-16 .sqn-results,
.zoom-17 .sqn-results {
    display: none;
}

@media screen and (min-width: 1280px) {
    /*     .sqn-results-wrapper .sqn-results-col:nth-child(2) {
        display: block;
    } */
}

@media screen and (min-width: 1900px) {

    .zoom-09 .sqn-results-wrapper .sqn-results-col:nth-child(3),
    .zoom-08 .sqn-results-wrapper .sqn-results-col:nth-child(3),
    .zoom-07 .sqn-results-wrapper .sqn-results-col:nth-child(3),
    .zoom-06 .sqn-results-wrapper .sqn-results-col:nth-child(3) {
        display: block;
    }
}

@media screen and (min-width: 1700px) {

    .zoom-08 .sqn-results-wrapper .sqn-results-col:nth-child(3),
    .zoom-07 .sqn-results-wrapper .sqn-results-col:nth-child(3),
    .zoom-06 .sqn-results-wrapper .sqn-results-col:nth-child(3) {
        display: block;
    }
}

@media screen and (min-width: 1600px) {
    .sqn-results-wrapper .sqn-results-col:nth-child(2) {
        display: block;
    }

    .sqn-tasksflow {
        width: 300px;
    }

    .sq-app-taskmanager .sqn-dashboard .sqn-dasboard-flex-container {
        padding-left: 300px;
    }

    .sqn-tasksflow .tm-tasks-list {
        width: 300px;
    }

    #sq-splitter-main.sq-app-taskmanager>div.split-pane-component-dashboard>div.sqn-dashboard-view.ng-scope.settings.active {
        left: 247px;
    }

    #sq-splitter-main.sq-app-taskmanager>div.split-pane-component-dashboard>div.sqn-dashboard-view.settings.active {
        left: 300px !important;
    }

    .sq-app-taskmanager .sqn-engine {
        width: 597px;
    }
}

@media screen and (min-width: 2000px) {
    .sqn-results-wrapper .sqn-results-col {
        display: block;
    }
}

/* 
@media screen and (min-height: 980px) {
    .engine-chart-box:nth-child(2) {
        display: block;
    }
}

@media screen and (min-height: 1200px) {
    .engine-chart-box:nth-child(3) {
        display: block;
    }
} */

@media screen and (max-width: 1560px) {
    .sq-app-taskmanager #optionsTab .col-lg-6 {
        width: 100%;
        float: none;
    }

    .sq-app-taskmanager #buildModeTab .col-lg-6 {
        width: 100%;
        float: none;
    }

    .sq-app-taskmanager .robustnessTest .col-lg-8 {
        width: 100%;
        float: none;
        margin-bottom: 20px;
    }

    .sq-app-taskmanager #ranking-settings {
        display: block;
    }

    .sq-app-taskmanager #ranking-settings .ranking-column-left {
        width: 100%;
        float: none;
        /* padding: 0; */
        margin-bottom: 14px;
    }

    .sq-app-taskmanager #ranking-settings .ranking-column-right {
        width: 100%;
        float: none;
    }

    .sq-app-taskmanager .additional-data-top-panel {
        top: 76px;
        width: 728px;
        padding-left: 0;
    }

    .sq-app-taskmanager .aditional-config-enabled {
        width: 46px;
        padding-right: 0;
        float: none;
        margin-left: 110px;
    }

    .sq-app-taskmanager .additional-config-all-timeframes {
        padding-left: 0;
        padding-right: 0;
        margin-top: 2px;
    }

    .sq-app-taskmanager .additional-config-precisions-to {
        padding-left: 0;
        padding-right: 0;
        margin-top: 2px;
    }
}

@media screen and (max-width: 1280px) {
    .sqn-engine .engine-container-instances {
        flex-wrap: wrap;
        margin: 0;
    }

    .engine-chart-box {
        flex: 0 0 100%;
        width: 100%;
        margin: 0;
        margin-bottom: 10px;
    }
}
.vis .overlay{position:absolute;top:0;left:0;width:100%;height:100%;z-index:10}.vis-active{box-shadow:0 0 10px #86d5f8}.vis [class*=span]{min-height:0;width:auto}div.vis-configuration{position:relative;display:block;float:left;font-size:12px}div.vis-configuration-wrapper{display:block;width:700px}div.vis-configuration-wrapper::after{clear:both;content:"";display:block}div.vis-configuration.vis-config-option-container{display:block;width:495px;background-color:#fff;border:2px solid #f7f8fa;border-radius:4px;margin-top:20px;left:10px;padding-left:5px}div.vis-configuration.vis-config-button{display:block;width:495px;height:25px;vertical-align:middle;line-height:25px;background-color:#f7f8fa;border:2px solid #ceced0;border-radius:4px;margin-top:20px;left:10px;padding-left:5px;cursor:pointer;margin-bottom:30px}div.vis-configuration.vis-config-button.hover{background-color:#4588e6;border:2px solid #214373;color:#fff}div.vis-configuration.vis-config-item{display:block;float:left;width:495px;height:25px;vertical-align:middle;line-height:25px}div.vis-configuration.vis-config-item.vis-config-s2{left:10px;background-color:#f7f8fa;padding-left:5px;border-radius:3px}div.vis-configuration.vis-config-item.vis-config-s3{left:20px;background-color:#e4e9f0;padding-left:5px;border-radius:3px}div.vis-configuration.vis-config-item.vis-config-s4{left:30px;background-color:#cfd8e6;padding-left:5px;border-radius:3px}div.vis-configuration.vis-config-header{font-size:18px;font-weight:700}div.vis-configuration.vis-config-label{width:120px;height:25px;line-height:25px}div.vis-configuration.vis-config-label.vis-config-s3{width:110px}div.vis-configuration.vis-config-label.vis-config-s4{width:100px}div.vis-configuration.vis-config-colorBlock{top:1px;width:30px;height:19px;border:1px solid #444;border-radius:2px;padding:0;margin:0;cursor:pointer}input.vis-configuration.vis-config-checkbox{left:-5px}input.vis-configuration.vis-config-rangeinput{position:relative;top:-5px;width:60px;padding:1px;margin:0;pointer-events:none}input.vis-configuration.vis-config-range{-webkit-appearance:none;border:0 solid #fff;background-color:rgba(0,0,0,0);width:300px;height:20px}input.vis-configuration.vis-config-range::-webkit-slider-runnable-track{width:300px;height:5px;background:#dedede;background:-moz-linear-gradient(top,#dedede 0,#c8c8c8 99%);background:-webkit-gradient(linear,left top,left bottom,color-stop(0,#dedede),color-stop(99%,#c8c8c8));background:-webkit-linear-gradient(top,#dedede 0,#c8c8c8 99%);background:-o-linear-gradient(top,#dedede 0,#c8c8c8 99%);background:-ms-linear-gradient(top,#dedede 0,#c8c8c8 99%);background:linear-gradient(to bottom,#dedede 0,#c8c8c8 99%);border:1px solid #999;box-shadow:#aaa 0 0 3px 0;border-radius:3px}input.vis-configuration.vis-config-range::-webkit-slider-thumb{-webkit-appearance:none;border:1px solid #14334b;height:17px;width:17px;border-radius:50%;background:#3876c2;background:-moz-linear-gradient(top,#3876c2 0,#385380 100%);background:-webkit-gradient(linear,left top,left bottom,color-stop(0,#3876c2),color-stop(100%,#385380));background:-webkit-linear-gradient(top,#3876c2 0,#385380 100%);background:-o-linear-gradient(top,#3876c2 0,#385380 100%);background:-ms-linear-gradient(top,#3876c2 0,#385380 100%);background:linear-gradient(to bottom,#3876c2 0,#385380 100%);box-shadow:#111927 0 0 1px 0;margin-top:-7px}input.vis-configuration.vis-config-range:focus{outline:0}input.vis-configuration.vis-config-range:focus::-webkit-slider-runnable-track{background:#9d9d9d;background:-moz-linear-gradient(top,#9d9d9d 0,#c8c8c8 99%);background:-webkit-gradient(linear,left top,left bottom,color-stop(0,#9d9d9d),color-stop(99%,#c8c8c8));background:-webkit-linear-gradient(top,#9d9d9d 0,#c8c8c8 99%);background:-o-linear-gradient(top,#9d9d9d 0,#c8c8c8 99%);background:-ms-linear-gradient(top,#9d9d9d 0,#c8c8c8 99%);background:linear-gradient(to bottom,#9d9d9d 0,#c8c8c8 99%)}input.vis-configuration.vis-config-range::-moz-range-track{width:300px;height:10px;background:#dedede;background:-moz-linear-gradient(top,#dedede 0,#c8c8c8 99%);background:-webkit-gradient(linear,left top,left bottom,color-stop(0,#dedede),color-stop(99%,#c8c8c8));background:-webkit-linear-gradient(top,#dedede 0,#c8c8c8 99%);background:-o-linear-gradient(top,#dedede 0,#c8c8c8 99%);background:-ms-linear-gradient(top,#dedede 0,#c8c8c8 99%);background:linear-gradient(to bottom,#dedede 0,#c8c8c8 99%);border:1px solid #999;box-shadow:#aaa 0 0 3px 0;border-radius:3px}input.vis-configuration.vis-config-range::-moz-range-thumb{border:none;height:16px;width:16px;border-radius:50%;background:#385380}input.vis-configuration.vis-config-range:-moz-focusring{outline:1px solid #fff;outline-offset:-1px}input.vis-configuration.vis-config-range::-ms-track{width:300px;height:5px;background:0 0;border-color:transparent;border-width:6px 0;color:transparent}input.vis-configuration.vis-config-range::-ms-fill-lower{background:#777;border-radius:10px}input.vis-configuration.vis-config-range::-ms-fill-upper{background:#ddd;border-radius:10px}input.vis-configuration.vis-config-range::-ms-thumb{border:none;height:16px;width:16px;border-radius:50%;background:#385380}input.vis-configuration.vis-config-range:focus::-ms-fill-lower{background:#888}input.vis-configuration.vis-config-range:focus::-ms-fill-upper{background:#ccc}.vis-configuration-popup{position:absolute;background:rgba(57,76,89,.85);border:2px solid #f2faff;line-height:30px;height:30px;width:150px;text-align:center;color:#fff;font-size:14px;border-radius:4px;-webkit-transition:opacity .3s ease-in-out;-moz-transition:opacity .3s ease-in-out;transition:opacity .3s ease-in-out}.vis-configuration-popup:after,.vis-configuration-popup:before{left:100%;top:50%;border:solid transparent;content:" ";height:0;width:0;position:absolute;pointer-events:none}.vis-configuration-popup:after{border-color:rgba(136,183,213,0);border-left-color:rgba(57,76,89,.85);border-width:8px;margin-top:-8px}.vis-configuration-popup:before{border-color:rgba(194,225,245,0);border-left-color:#f2faff;border-width:12px;margin-top:-12px}div.vis-tooltip{position:absolute;visibility:hidden;padding:5px;white-space:nowrap;font-family:verdana;font-size:14px;color:#000;background-color:#f5f4ed;-moz-border-radius:3px;-webkit-border-radius:3px;border-radius:3px;border:1px solid #808074;box-shadow:3px 3px 10px rgba(0,0,0,.2);pointer-events:none;z-index:5}div.vis-color-picker{position:absolute;top:0;left:30px;margin-top:-140px;margin-left:30px;width:310px;height:444px;z-index:1;padding:10px;border-radius:15px;background-color:#fff;display:none;box-shadow:rgba(0,0,0,.5) 0 0 10px 0}div.vis-color-picker div.vis-arrow{position:absolute;top:147px;left:5px}div.vis-color-picker div.vis-arrow::after,div.vis-color-picker div.vis-arrow::before{right:100%;top:50%;border:solid transparent;content:" ";height:0;width:0;position:absolute;pointer-events:none}div.vis-color-picker div.vis-arrow:after{border-color:rgba(255,255,255,0);border-right-color:#fff;border-width:30px;margin-top:-30px}div.vis-color-picker div.vis-color{position:absolute;width:289px;height:289px;cursor:pointer}div.vis-color-picker div.vis-brightness{position:absolute;top:313px}div.vis-color-picker div.vis-opacity{position:absolute;top:350px}div.vis-color-picker div.vis-selector{position:absolute;top:137px;left:137px;width:15px;height:15px;border-radius:15px;border:1px solid #fff;background:#4c4c4c;background:-moz-linear-gradient(top,#4c4c4c 0,#595959 12%,#666 25%,#474747 39%,#2c2c2c 50%,#000 51%,#111 60%,#2b2b2b 76%,#1c1c1c 91%,#131313 100%);background:-webkit-gradient(linear,left top,left bottom,color-stop(0,#4c4c4c),color-stop(12%,#595959),color-stop(25%,#666),color-stop(39%,#474747),color-stop(50%,#2c2c2c),color-stop(51%,#000),color-stop(60%,#111),color-stop(76%,#2b2b2b),color-stop(91%,#1c1c1c),color-stop(100%,#131313));background:-webkit-linear-gradient(top,#4c4c4c 0,#595959 12%,#666 25%,#474747 39%,#2c2c2c 50%,#000 51%,#111 60%,#2b2b2b 76%,#1c1c1c 91%,#131313 100%);background:-o-linear-gradient(top,#4c4c4c 0,#595959 12%,#666 25%,#474747 39%,#2c2c2c 50%,#000 51%,#111 60%,#2b2b2b 76%,#1c1c1c 91%,#131313 100%);background:-ms-linear-gradient(top,#4c4c4c 0,#595959 12%,#666 25%,#474747 39%,#2c2c2c 50%,#000 51%,#111 60%,#2b2b2b 76%,#1c1c1c 91%,#131313 100%);background:linear-gradient(to bottom,#4c4c4c 0,#595959 12%,#666 25%,#474747 39%,#2c2c2c 50%,#000 51%,#111 60%,#2b2b2b 76%,#1c1c1c 91%,#131313 100%)}div.vis-color-picker div.vis-new-color{position:absolute;width:140px;height:20px;border:1px solid rgba(0,0,0,.1);border-radius:5px;top:380px;left:159px;text-align:right;padding-right:2px;font-size:10px;color:rgba(0,0,0,.4);vertical-align:middle;line-height:20px}div.vis-color-picker div.vis-initial-color{position:absolute;width:140px;height:20px;border:1px solid rgba(0,0,0,.1);border-radius:5px;top:380px;left:10px;text-align:left;padding-left:2px;font-size:10px;color:rgba(0,0,0,.4);vertical-align:middle;line-height:20px}div.vis-color-picker div.vis-label{position:absolute;width:300px;left:10px}div.vis-color-picker div.vis-label.vis-brightness{top:300px}div.vis-color-picker div.vis-label.vis-opacity{top:338px}div.vis-color-picker div.vis-button{position:absolute;width:68px;height:25px;border-radius:10px;vertical-align:middle;text-align:center;line-height:25px;top:410px;border:2px solid #d9d9d9;background-color:#f7f7f7;cursor:pointer}div.vis-color-picker div.vis-button.vis-cancel{left:5px}div.vis-color-picker div.vis-button.vis-load{left:82px}div.vis-color-picker div.vis-button.vis-apply{left:159px}div.vis-color-picker div.vis-button.vis-save{left:236px}div.vis-color-picker input.vis-range{width:290px;height:20px}div.vis-network div.vis-manipulation{box-sizing:content-box;border-width:0;border-bottom:1px;border-style:solid;border-color:#d6d9d8;background:#fff;background:-moz-linear-gradient(top,#fff 0,#fcfcfc 48%,#fafafa 50%,#fcfcfc 100%);background:-webkit-gradient(linear,left top,left bottom,color-stop(0,#fff),color-stop(48%,#fcfcfc),color-stop(50%,#fafafa),color-stop(100%,#fcfcfc));background:-webkit-linear-gradient(top,#fff 0,#fcfcfc 48%,#fafafa 50%,#fcfcfc 100%);background:-o-linear-gradient(top,#fff 0,#fcfcfc 48%,#fafafa 50%,#fcfcfc 100%);background:-ms-linear-gradient(top,#fff 0,#fcfcfc 48%,#fafafa 50%,#fcfcfc 100%);background:linear-gradient(to bottom,#fff 0,#fcfcfc 48%,#fafafa 50%,#fcfcfc 100%);padding-top:4px;position:absolute;left:0;top:0;width:100%;height:28px}div.vis-network div.vis-edit-mode{position:absolute;left:0;top:5px;height:30px}div.vis-network div.vis-close{position:absolute;right:0;top:0;width:30px;height:30px;background-position:20px 3px;background-repeat:no-repeat;background-image:url(img/network/cross.png);cursor:pointer;-webkit-touch-callout:none;-webkit-user-select:none;-khtml-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}div.vis-network div.vis-close:hover{opacity:.6}div.vis-network div.vis-edit-mode div.vis-button,div.vis-network div.vis-manipulation div.vis-button{float:left;font-family:verdana;font-size:12px;-moz-border-radius:15px;border-radius:15px;display:inline-block;background-position:0 0;background-repeat:no-repeat;height:24px;margin-left:10px;cursor:pointer;padding:0 8px 0 8px;-webkit-touch-callout:none;-webkit-user-select:none;-khtml-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}div.vis-network div.vis-manipulation div.vis-button:hover{box-shadow:1px 1px 8px rgba(0,0,0,.2)}div.vis-network div.vis-manipulation div.vis-button:active{box-shadow:1px 1px 8px rgba(0,0,0,.5)}div.vis-network div.vis-manipulation div.vis-button.vis-back{background-image:url(img/network/backIcon.png)}div.vis-network div.vis-manipulation div.vis-button.vis-none:hover{box-shadow:1px 1px 8px transparent;cursor:default}div.vis-network div.vis-manipulation div.vis-button.vis-none:active{box-shadow:1px 1px 8px transparent}div.vis-network div.vis-manipulation div.vis-button.vis-none{padding:0}div.vis-network div.vis-manipulation div.notification{margin:2px;font-weight:700}div.vis-network div.vis-manipulation div.vis-button.vis-add{background-image:url(img/network/addNodeIcon.png)}div.vis-network div.vis-edit-mode div.vis-button.vis-edit,div.vis-network div.vis-manipulation div.vis-button.vis-edit{background-image:url(img/network/editIcon.png)}div.vis-network div.vis-edit-mode div.vis-button.vis-edit.vis-edit-mode{background-color:#fcfcfc;border:1px solid #ccc}div.vis-network div.vis-manipulation div.vis-button.vis-connect{background-image:url(img/network/connectIcon.png)}div.vis-network div.vis-manipulation div.vis-button.vis-delete{background-image:url(img/network/deleteIcon.png)}div.vis-network div.vis-edit-mode div.vis-label,div.vis-network div.vis-manipulation div.vis-label{margin:0 0 0 23px;line-height:25px}div.vis-network div.vis-manipulation div.vis-separator-line{float:left;display:inline-block;width:1px;height:21px;background-color:#bdbdbd;margin:0 7px 0 15px}div.vis-network div.vis-navigation div.vis-button{width:34px;height:34px;-moz-border-radius:17px;border-radius:17px;position:absolute;display:inline-block;background-position:2px 2px;background-repeat:no-repeat;cursor:pointer;-webkit-touch-callout:none;-webkit-user-select:none;-khtml-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}div.vis-network div.vis-navigation div.vis-button:hover{box-shadow:0 0 3px 3px rgba(56,207,21,.3)}div.vis-network div.vis-navigation div.vis-button:active{box-shadow:0 0 1px 3px rgba(56,207,21,.95)}div.vis-network div.vis-navigation div.vis-button.vis-up{background-image:url(img/network/upArrow.png);bottom:50px;left:55px}div.vis-network div.vis-navigation div.vis-button.vis-down{background-image:url(img/network/downArrow.png);bottom:10px;left:55px}div.vis-network div.vis-navigation div.vis-button.vis-left{background-image:url(img/network/leftArrow.png);bottom:10px;left:15px}div.vis-network div.vis-navigation div.vis-button.vis-right{background-image:url(img/network/rightArrow.png);bottom:10px;left:95px}div.vis-network div.vis-navigation div.vis-button.vis-zoomIn{background-image:url(img/network/plus.png);bottom:10px;right:15px}div.vis-network div.vis-navigation div.vis-button.vis-zoomOut{background-image:url(img/network/minus.png);bottom:10px;right:55px}div.vis-network div.vis-navigation div.vis-button.vis-zoomExtends{background-image:url(img/network/zoomExtends.png);bottom:50px;right:15px}.vis-current-time{background-color:#ff7f6e;width:2px;z-index:1;pointer-events:none}.vis-rolling-mode-btn{height:40px;width:40px;position:absolute;top:7px;right:20px;border-radius:50%;font-size:28px;cursor:pointer;opacity:.8;color:#fff;font-weight:700;text-align:center;background:#3876c2}.vis-rolling-mode-btn:before{content:"\26F6"}.vis-rolling-mode-btn:hover{opacity:1}.vis-custom-time{background-color:#6e94ff;width:2px;cursor:move;z-index:1}.vis-panel.vis-background.vis-horizontal .vis-grid.vis-horizontal{position:absolute;width:100%;height:0;border-bottom:1px solid}.vis-panel.vis-background.vis-horizontal .vis-grid.vis-minor{border-color:#e5e5e5}.vis-panel.vis-background.vis-horizontal .vis-grid.vis-major{border-color:#bfbfbf}.vis-data-axis .vis-y-axis.vis-major{width:100%;position:absolute;color:#4d4d4d;white-space:nowrap}.vis-data-axis .vis-y-axis.vis-major.vis-measure{padding:0;margin:0;border:0;visibility:hidden;width:auto}.vis-data-axis .vis-y-axis.vis-minor{position:absolute;width:100%;color:#bebebe;white-space:nowrap}.vis-data-axis .vis-y-axis.vis-minor.vis-measure{padding:0;margin:0;border:0;visibility:hidden;width:auto}.vis-data-axis .vis-y-axis.vis-title{position:absolute;color:#4d4d4d;white-space:nowrap;bottom:20px;text-align:center}.vis-data-axis .vis-y-axis.vis-title.vis-measure{padding:0;margin:0;visibility:hidden;width:auto}.vis-data-axis .vis-y-axis.vis-title.vis-left{bottom:0;-webkit-transform-origin:left top;-moz-transform-origin:left top;-ms-transform-origin:left top;-o-transform-origin:left top;transform-origin:left bottom;-webkit-transform:rotate(-90deg);-moz-transform:rotate(-90deg);-ms-transform:rotate(-90deg);-o-transform:rotate(-90deg);transform:rotate(-90deg)}.vis-data-axis .vis-y-axis.vis-title.vis-right{bottom:0;-webkit-transform-origin:right bottom;-moz-transform-origin:right bottom;-ms-transform-origin:right bottom;-o-transform-origin:right bottom;transform-origin:right bottom;-webkit-transform:rotate(90deg);-moz-transform:rotate(90deg);-ms-transform:rotate(90deg);-o-transform:rotate(90deg);transform:rotate(90deg)}.vis-legend{background-color:rgba(247,252,255,.65);padding:5px;border:1px solid #b3b3b3;box-shadow:2px 2px 10px rgba(154,154,154,.55)}.vis-legend-text{white-space:nowrap;display:inline-block}.vis-item{position:absolute;color:#1a1a1a;border-color:#97b0f8;border-width:1px;background-color:#d5ddf6;display:inline-block;z-index:1}.vis-item.vis-selected{border-color:#ffc200;background-color:#fff785;z-index:2}.vis-editable.vis-selected{cursor:move}.vis-item.vis-point.vis-selected{background-color:#fff785}.vis-item.vis-box{text-align:center;border-style:solid;border-radius:2px}.vis-item.vis-point{background:0 0}.vis-item.vis-dot{position:absolute;padding:0;border-width:4px;border-style:solid;border-radius:4px}.vis-item.vis-range{border-style:solid;border-radius:2px;box-sizing:border-box}.vis-item.vis-background{border:none;background-color:rgba(213,221,246,.4);box-sizing:border-box;padding:0;margin:0}.vis-item .vis-item-overflow{position:relative;width:100%;height:100%;padding:0;margin:0;overflow:hidden}.vis-item-visible-frame{white-space:nowrap}.vis-item.vis-range .vis-item-content{position:relative;display:inline-block}.vis-item.vis-background .vis-item-content{position:absolute;display:inline-block}.vis-item.vis-line{padding:0;position:absolute;width:0;border-left-width:1px;border-left-style:solid}.vis-item .vis-item-content{white-space:nowrap;box-sizing:border-box;padding:5px}.vis-item .vis-onUpdateTime-tooltip{position:absolute;background:#4f81bd;color:#fff;width:200px;text-align:center;white-space:nowrap;padding:5px;border-radius:1px;transition:.4s;-o-transition:.4s;-moz-transition:.4s;-webkit-transition:.4s}.vis-item .vis-delete,.vis-item .vis-delete-rtl{position:absolute;top:0;width:24px;height:24px;box-sizing:border-box;padding:0 5px;cursor:pointer;-webkit-transition:background .2s linear;-moz-transition:background .2s linear;-ms-transition:background .2s linear;-o-transition:background .2s linear;transition:background .2s linear}.vis-item .vis-delete{right:-24px}.vis-item .vis-delete-rtl{left:-24px}.vis-item .vis-delete-rtl:after,.vis-item .vis-delete:after{content:"\00D7";color:red;font-family:arial,sans-serif;font-size:22px;font-weight:700;-webkit-transition:color .2s linear;-moz-transition:color .2s linear;-ms-transition:color .2s linear;-o-transition:color .2s linear;transition:color .2s linear}.vis-item .vis-delete-rtl:hover,.vis-item .vis-delete:hover{background:red}.vis-item .vis-delete-rtl:hover:after,.vis-item .vis-delete:hover:after{color:#fff}.vis-item .vis-drag-center{position:absolute;width:100%;height:100%;top:0;left:0;cursor:move}.vis-item.vis-range .vis-drag-left{position:absolute;width:24px;max-width:20%;min-width:2px;height:100%;top:0;left:-4px;cursor:w-resize}.vis-item.vis-range .vis-drag-right{position:absolute;width:24px;max-width:20%;min-width:2px;height:100%;top:0;right:-4px;cursor:e-resize}.vis-range.vis-item.vis-readonly .vis-drag-left,.vis-range.vis-item.vis-readonly .vis-drag-right{cursor:auto}.vis-itemset{position:relative;padding:0;margin:0;box-sizing:border-box}.vis-itemset .vis-background,.vis-itemset .vis-foreground{position:absolute;width:100%;height:100%;overflow:visible}.vis-axis{position:absolute;width:100%;height:0;left:0;z-index:1}.vis-foreground .vis-group{position:relative;box-sizing:border-box;border-bottom:1px solid #bfbfbf}.vis-foreground .vis-group:last-child{border-bottom:none}.vis-nesting-group{cursor:pointer}.vis-nested-group{background:#f5f5f5}.vis-label.vis-nesting-group.expanded:before{content:"\25BC"}.vis-label.vis-nesting-group.collapsed-rtl:before{content:"\25C0"}.vis-label.vis-nesting-group.collapsed:before{content:"\25B6"}.vis-overlay{position:absolute;top:0;left:0;width:100%;height:100%;z-index:10}.vis-labelset{position:relative;overflow:hidden;box-sizing:border-box}.vis-labelset .vis-label{position:relative;left:0;top:0;width:100%;color:#4d4d4d;box-sizing:border-box}.vis-labelset .vis-label{border-bottom:1px solid #bfbfbf}.vis-labelset .vis-label.draggable{cursor:pointer}.vis-labelset .vis-label:last-child{border-bottom:none}.vis-labelset .vis-label .vis-inner{display:inline-block;padding:5px}.vis-labelset .vis-label .vis-inner.vis-hidden{padding:0}.vis-panel{position:absolute;padding:0;margin:0;box-sizing:border-box}.vis-panel.vis-bottom,.vis-panel.vis-center,.vis-panel.vis-left,.vis-panel.vis-right,.vis-panel.vis-top{border:1px #bfbfbf}.vis-panel.vis-center,.vis-panel.vis-left,.vis-panel.vis-right{border-top-style:solid;border-bottom-style:solid;overflow:hidden}.vis-left.vis-panel.vis-vertical-scroll,.vis-right.vis-panel.vis-vertical-scroll{height:100%;overflow-x:hidden;overflow-y:scroll}.vis-left.vis-panel.vis-vertical-scroll{direction:rtl}.vis-left.vis-panel.vis-vertical-scroll .vis-content{direction:ltr}.vis-right.vis-panel.vis-vertical-scroll{direction:ltr}.vis-right.vis-panel.vis-vertical-scroll .vis-content{direction:rtl}.vis-panel.vis-bottom,.vis-panel.vis-center,.vis-panel.vis-top{border-left-style:solid;border-right-style:solid}.vis-background{overflow:hidden}.vis-panel>.vis-content{position:relative}.vis-panel .vis-shadow{position:absolute;width:100%;height:1px;box-shadow:0 0 10px rgba(0,0,0,.8)}.vis-panel .vis-shadow.vis-top{top:-1px;left:0}.vis-panel .vis-shadow.vis-bottom{bottom:-1px;left:0}.vis-graph-group0{fill:#4f81bd;fill-opacity:0;stroke-width:2px;stroke:#4f81bd}.vis-graph-group1{fill:#f79646;fill-opacity:0;stroke-width:2px;stroke:#f79646}.vis-graph-group2{fill:#8c51cf;fill-opacity:0;stroke-width:2px;stroke:#8c51cf}.vis-graph-group3{fill:#75c841;fill-opacity:0;stroke-width:2px;stroke:#75c841}.vis-graph-group4{fill:#ff0100;fill-opacity:0;stroke-width:2px;stroke:#ff0100}.vis-graph-group5{fill:#37d8e6;fill-opacity:0;stroke-width:2px;stroke:#37d8e6}.vis-graph-group6{fill:#042662;fill-opacity:0;stroke-width:2px;stroke:#042662}.vis-graph-group7{fill:#00ff26;fill-opacity:0;stroke-width:2px;stroke:#00ff26}.vis-graph-group8{fill:#f0f;fill-opacity:0;stroke-width:2px;stroke:#f0f}.vis-graph-group9{fill:#8f3938;fill-opacity:0;stroke-width:2px;stroke:#8f3938}.vis-timeline .vis-fill{fill-opacity:.1;stroke:none}.vis-timeline .vis-bar{fill-opacity:.5;stroke-width:1px}.vis-timeline .vis-point{stroke-width:2px;fill-opacity:1}.vis-timeline .vis-legend-background{stroke-width:1px;fill-opacity:.9;fill:#fff;stroke:#c2c2c2}.vis-timeline .vis-outline{stroke-width:1px;fill-opacity:1;fill:#fff;stroke:#e5e5e5}.vis-timeline .vis-icon-fill{fill-opacity:.3;stroke:none}.vis-time-axis{position:relative;overflow:hidden}.vis-time-axis.vis-foreground{top:0;left:0;width:100%}.vis-time-axis.vis-background{position:absolute;top:0;left:0;width:100%;height:100%}.vis-time-axis .vis-text{position:absolute;color:#4d4d4d;padding:3px;overflow:hidden;box-sizing:border-box;white-space:nowrap}.vis-time-axis .vis-text.vis-measure{position:absolute;padding-left:0;padding-right:0;margin-left:0;margin-right:0;visibility:hidden}.vis-time-axis .vis-grid.vis-vertical{position:absolute;border-left:1px solid}.vis-time-axis .vis-grid.vis-vertical-rtl{position:absolute;border-right:1px solid}.vis-time-axis .vis-grid.vis-minor{border-color:#e5e5e5}.vis-time-axis .vis-grid.vis-major{border-color:#bfbfbf}.vis-timeline{position:relative;border:1px solid #bfbfbf;overflow:hidden;padding:0;margin:0;box-sizing:border-box}
#ribbon{
    min-height: 40px;
    padding: 0 13px;    
    background: rgba(255,255,255,.4);
}

#ribbon .breadcrumb {
    display: inline-block;
    margin: 0;
    padding: 11px 34px 11px 0!important;
    background: 0 0;
    vertical-align: top;
    color: #7C7C7C!important;
}

#ribbon .breadcrumb li:last-child {
    color: #374850!important;
}

.quantbox {
    border: 2px solid #e6e6e6;
    margin-bottom: 30px;
    -webkit-border-radius: 1px;
    -moz-border-radius: 1px;
    border-radius: 2px;
    background-color: #ffffff;
    display: block;
}

.quantbox .inner {
    border: 1px solid #d2d2d2;
    border-radius: 0;
    margin: 0;
    background-color: #ffffff;
    position: relative;
}

.quantbox .inner .widget-body {
	padding: 13px 8px 9px 8px;
}

.quantbox:after, .quantbox .inner:after {
    content: "\0020";
    display: block;
    height: 0;
    overflow: hidden;
    font-size: 0;
    line-height: 0;
    visibility: hidden;
    clear: both;
}

.row-gutter-small {
    margin-left: -7px;
    margin-right: -7px;
}

.row-gutter-small > div {
    padding-left: 7px;
    padding-right: 7px;

}

.row-gutter-small .quantbox {
    margin-bottom: 15px;
}

.title-main {
    font-size: 28px;
    margin-bottom: 15px;
    font-weight: 300;
}

.title-second {
    margin: 0;
    font-weight: bold;
    margin-top: 8px;
    margin-bottom: 8px;
    font-size: 20px;
}

.title-third {
    margin: 0;
    margin-top: 8px;
    margin-bottom: 8px;
    font-weight: 600;
    color: #7c7c7c;
    font-size: 18px;
}

.dasboard-getting-started {
    margin-bottom: 13px;
    width: 100%;
    position: relative;
}

.dasboard-getting-started .inner {
    width: 100%;
    display: -webkit-flex;
    display: -ms-flexbox;
    display: flex;
 
    -webkit-flex-wrap: wrap;
    -ms-flex-wrap: wrap;
    flex-wrap: wrap;
}

.dasboard-getting-started .widget-part {
    margin-top: 9px;
    margin-bottom: 9px;
    padding-right: 9px;
    padding-left: 10px;
    padding-bottom: 8px;
    border-right: 1px solid #dfdfdf!important;
    background-color: #ffffff;
    float: left;
    padding-top: 0;
    position: relative;
}

.dasboard-getting-started .widget-part.widget-part-1 {
    width: 16.25%;
    min-width: 140px;
}
.dasboard-getting-started .widget-part.widget-part-2 {
    width: 25.4%;
    min-width: 200px;
}
.dasboard-getting-started .widget-part.widget-part-3 {
    width: 24.6%;
    min-width: 180px;
}
.dasboard-getting-started .widget-part.widget-part-4 {
    width: 21%;
    border-right: 0!important;
    padding-right: 0;
    min-width: 200;
}
.dasboard-getting-started .widget-part.widget-part-5 {
    width: 12.75%;
    border-right: 0!important;
    min-width: 120;
}

.dasboard-getting-started .title-main {
    line-height: 30px;
    clear: both;
    margin-top: 5px;
    margin-left: 6px;
    margin-bottom: 10px;
    font-weight: 400;
}

.dasboard-getting-started .widget-part-1 label {
    display: block;
    color: #7c7c7c;
    font-size: 13px;
    margin-bottom: 0;
    cursor: pointer;
    margin-left: 10px;
}

.dasboard-getting-started .widget-part-1 label input {
    vertical-align: -2px;
    margin-right: 8px;
    cursor: pointer;
}

.dasboard-getting-started .widget-part-5 .btn {
    position: absolute;
    bottom: 10px;
}

.dasboard-getting-started .widget-number {
    position: absolute;
    top: 0;
    left: 9px;
    border: 2px solid #2497f3;
    width: 51px;
    height: 51px;
    display: block;
    line-height: 47px;
    text-align: center;
    color: #2497f3;
    font-weight: 500;
    font-size: 32px;
    border-radius: 50%;
}

.dasboard-getting-started .title-second {
    margin-left: 60px;
    clear: both;
    margin-top: 4px;
    margin-bottom: 3px;
}

.dasboard-getting-started .text-smaller {
    margin-left: 60px;
    clear: both;
    color: #7c7c7c;
}

.jarviswidget>header {
    border-bottom: 0;
    background-color: #f5f5f5;
    height: 40px;
}

.jarviswidget>header h2 {
    line-height: 40px;
    font-size: 15px;
}

.title-blue {
    margin: 0;
    padding: 0;
    font-size: 14px;
    font-weight: bold;
    color: #2196f3;
}

.widget-close {
    display: block;
    width: 28px;
    height: 28px;
    border: 1px solid #ececec;
    border-radius: 1px;
    color: #ececec;
    position: absolute;
    top: 9px;
    right: 9px;
    font-size: 28px;
    text-align: center;
    line-height: 24px;
}

.widget-close:hover {
    color: #7c7c7c;
    border-color: #dfdfdf;
    background-color: #ececec;
}

.tasks-lines .quantbox {
    margin-bottom: 8px;
}

.tasks-lines .quantbox .widget-body {
    font-size: 15px;
}

.tasks-lines .quantbox .widget-body span {
    font-weight: 300;
}

.tasks-lines .quantbox:hover {
    /*
    border: 2px solid #dcdcdc;
    outline: 1px solid #dcdcdc;
    */
    border: 3px solid #dcdcdc;
    border-radius: 3px;
    margin-left: -1px;    
    margin-right: -1px;    
    margin-top: -2px;    
    position: relative;
    top: 1px;
}

.title-link {
    font-size: 14px;
    color: #2196f3;
    float: right;
    font-weight: 400;
    margin-top: 5px;
    margin-right: 6px;
}

.newtask-ico {
    text-align: center;
    cursor: pointer;
}

.newtask-ico.quantbox:hover {
    /*
    border: 2px solid #dcdcdc;
    outline: 1px solid #dcdcdc;
    */
    border: 3px solid #dcdcdc;
    border-radius: 3px;
    margin: -1px;
}

.newtask-ico .widget-body {
    padding-top: 28px;
    font-weight: bold;
    font-size: 14px;
}    

.newtask-ico i {
    font-size: 48px;
    clear: both;
    margin-bottom: 3px;
}

.newtask-ico-strategy {
    color: #2196f3;
}

.newtask-ico-strategy .widget-body {
    border-top: 4px solid #2196f3;
}

.newtask-ico-retest {
    color: #c00000;
}

.newtask-ico-retest .widget-body {
    border-top: 4px solid #c00000;
}

.newtask-ico-optimize {
    color: #fe9b19;
}

.newtask-ico-optimize .widget-body {
    border-top: 4px solid #fe9b19;
}

.newtask-ico-strategy:hover {
    color: #2196f3;
}

.newtask-ico-retest:hover {
    color: #c00000;
}

.newtask-ico-optimize:hover {
    color: #fe9b19;
}

.newtask-ico:hover .widget-body {
    border-width: 8px;
    padding-top: 9px;
}

.sampletasks .quantbox .inner {
    min-height: 280px;
}

.widget-header {
    background-color: #f5f5f5;
    /* height: 40px; */
    line-height: 15px;
    font-size: 15px;
    margin: 0;
    padding-left: 14px;
    padding-top: 13px;
    padding-bottom: 12px;
}

.sampletasks .title-link {
    margin: 0;
    padding: 0;
    font-size: 14px;
    font-weight: 600;
    color: #2196f3;
    display: block;
    float: none;
}

.sampletasks p {
    font-size: 15px;
    color: #7c7c7c;
}

.sampletasks .widget-body {
    border-bottom: 1px solid #dfdfdf!important;
}

.sampletasks .widget-body:last-of-type {
    border-bottom: 0!important;
}

.dashboard-links {
    margin: 0;
    padding: 0;
    list-style-type: none;
    border-top: 1px solid #dfdfdf;
    margin-top: 4px;
}

.dashboard-links li {
    margin: 0;
    padding: 0;
    /* height: 48px; */
    line-height: 15px;
    padding-top: 17px;
    padding-bottom: 12px;
    display: block;
    border-bottom: 1px solid #dfdfdf;
    padding-left: 10px;
    color: #2196f3;
}

.dashboard-links li i {
    font-size: 18px;
    margin-right: 6px;
    vertical-align: middle;
}

.dashboard-links li a {
    font-size: 14px;
    color: #2196f3;
    vertical-align: middle;
}

.dashboard-links li a:hover {
    text-decoration: underline;
}

.icon-box {
    display: inline-block;
    width: 18px;
    height: 18px;
    background-color: #2196f3;
    border-radius: 2px;
}

#content {    
    position: relative;
    /*max-width: 1280px;*/
}

.content-limiter {
    max-width: 1280px;
    padding: 10px 14px;
}
.sq-splitter {
    display: flex;
    flex-direction: column;
}

.sq-splitter>div:first-child {
    position: relative;
    flex-basis: 100%;
}

.sq-splitter>div:last-child {
    flex: 1 1 auto;
    position: relative;
}

.sq-splitter.active>div:last-child {
    min-height: 100px;
}

.sq-splitter .resizer-container {
    position: absolute;
    left: 50%;
    width: 200px;
    margin-left: -100px;
    text-align: center;
    top: 3px;
    height: 8px;
    z-index: 100;
}

.sq-splitter.active .resizer-container {
    top: 0;
}

.sq-splitter .resizer-container .resizer {
    cursor: row-resize;
    display: none;
    background-image: url(../../img/split-divider-small.png);
    width: 30px;
    height: 9px;
    margin-right: 6px;
}

.sq-splitter .resizer-container .opener {
    display: inline-block;
    cursor: pointer;
    background-image: url(../../img/databank-opener-open.png);
    width: 31px;
    height: 11px;
}

.sq-splitter.active .resizer-container>div {
    vertical-align: top;
}

.sq-splitter.active .resizer-container .resizer {
    display: inline-block;
}

.sq-splitter.active .resizer-container .opener {
    background-image: url(../../img/databank-opener-close.png);
    width: 30px;
    height: 9px;
}

.sq-splitter .resizer-container .maximizer {
    display: none;
}

.sq-splitter.active .resizer-container .maximizer {
    cursor: pointer;
    display: inline-block;
    background-image: url(../../img/databank-opener-maximise.png);
    margin-right: 6px;
    width: 30px;
    height: 9px;
}

.sq-splitter.maximised .resizer-container .maximizer {
    display: none;
}

.sq-splitter.maximised .resizer-container .opener {
    display: none;
}

.sq-splitter.maximised .resizer-container .resizer {
    display: none;
}

.sq-splitter.maximised>div:first-child {
    flex-basis: 0 !important;
}

.sq-splitter .resizer-container .normalizer {
    display: none;
}

.sq-splitter.maximised .resizer-container .normalizer {
    cursor: pointer;
    display: inline-block;
    background-image: url(../../img/databank-opener-close.png);
    width: 30px;
    height: 9px;
}
/* Chosen v1.7.0 | (c) 2011-2017 by Harvest | MIT License, https://github.com/harvesthq/chosen/blob/master/LICENSE.md */

.chosen-container{position:relative;display:inline-block;vertical-align:middle;font-size:13px;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.chosen-container *{box-sizing:border-box}.chosen-container .chosen-drop{position:absolute;top:100%;z-index:1010;width:100%;border:1px solid #aaa;border-top:0;background:#fff;box-shadow:0 4px 5px rgba(0,0,0,.15);clip:rect(0,0,0,0)}.chosen-container.chosen-with-drop .chosen-drop{clip:auto}.chosen-container a{cursor:pointer}.chosen-container .search-choice .group-name,.chosen-container .chosen-single .group-name{margin-right:4px;overflow:hidden;white-space:nowrap;text-overflow:ellipsis;font-weight:400;color:#999}.chosen-container .search-choice .group-name:after,.chosen-container .chosen-single .group-name:after{content:":";padding-left:2px;vertical-align:top}.chosen-container-single .chosen-single{position:relative;display:block;overflow:hidden;padding:0 0 0 8px;height:25px;border:1px solid #aaa;border-radius:5px;background-color:#fff;background:linear-gradient(#fff 20%,#f6f6f6 50%,#eee 52%,#f4f4f4 100%);background-clip:padding-box;box-shadow:0 0 3px #fff inset,0 1px 1px rgba(0,0,0,.1);color:#444;text-decoration:none;white-space:nowrap;line-height:24px}.chosen-container-single .chosen-default{color:#999}.chosen-container-single .chosen-single span{display:block;overflow:hidden;margin-right:26px;text-overflow:ellipsis;white-space:nowrap}.chosen-container-single .chosen-single-with-deselect span{margin-right:38px}.chosen-container-single .chosen-single abbr{position:absolute;top:6px;right:26px;display:block;width:12px;height:12px;background:url(../../img/chosen-sprite.png) -42px 1px no-repeat;font-size:1px}.chosen-container-single .chosen-single abbr:hover{background-position:-42px -10px}.chosen-container-single.chosen-disabled .chosen-single abbr:hover{background-position:-42px -10px}.chosen-container-single .chosen-single div{position:absolute;top:0;right:0;display:block;width:18px;height:100%}.chosen-container-single .chosen-single div b{display:block;width:100%;height:100%;background:url(../../img/chosen-sprite.png) no-repeat 0 2px}.chosen-container-single .chosen-search{position:relative;z-index:1010;margin:0;padding:3px 4px;white-space:nowrap}.chosen-container-single .chosen-search input[type=text]{margin:1px 0;padding:4px 20px 4px 5px;width:100%;height:auto;outline:0;border:1px solid #aaa;background:url(../../img/chosen-sprite.png) no-repeat 100% -20px;font-size:1em;font-family:sans-serif;line-height:normal;border-radius:0}.chosen-container-single .chosen-drop{margin-top:-1px;border-radius:0 0 4px 4px;background-clip:padding-box}.chosen-container-single.chosen-container-single-nosearch .chosen-search{position:absolute;clip:rect(0,0,0,0)}.chosen-container .chosen-results{color:#444;position:relative;overflow-x:hidden;overflow-y:auto;margin:0 4px 4px 0;padding:0 0 0 4px;max-height:240px;-webkit-overflow-scrolling:touch}.chosen-container .chosen-results li{display:none;margin:0;padding:5px 6px;list-style:none;line-height:15px;word-wrap:break-word;-webkit-touch-callout:none}.chosen-container .chosen-results li.active-result{display:list-item;cursor:pointer}.chosen-container .chosen-results li.disabled-result{display:list-item;color:#ccc;cursor:default}.chosen-container .chosen-results li.highlighted{background-color:#3875d7;background-image:linear-gradient(#3875d7 20%,#2a62bc 90%);color:#fff}.chosen-container .chosen-results li.no-results{color:#777;display:list-item;background:#f4f4f4}.chosen-container .chosen-results li.group-result{display:list-item;font-weight:700;cursor:default}.chosen-container .chosen-results li.group-option{padding-left:15px}.chosen-container .chosen-results li em{font-style:normal;text-decoration:underline}.chosen-container-multi .chosen-choices{position:relative;overflow:hidden;margin:0;padding:0 5px;width:100%;height:auto;border:1px solid #aaa;background-color:#fff;background-image:linear-gradient(#eee 1%,#fff 15%);cursor:text}.chosen-container-multi .chosen-choices li{float:left;list-style:none}.chosen-container-multi .chosen-choices li.search-field{margin:0;padding:0;white-space:nowrap}.chosen-container-multi .chosen-choices li.search-field input[type=text]{margin:1px 0;padding:0;height:25px;outline:0;border:0!important;background:transparent!important;box-shadow:none;color:#999;font-size:100%;font-family:sans-serif;line-height:normal;border-radius:0;width:25px}.chosen-container-multi .chosen-choices li.search-choice{position:relative;margin:3px 5px 3px 0;padding:3px 20px 3px 5px;border:1px solid #aaa;max-width:100%;border-radius:3px;background-color:#eee;background-image:linear-gradient(#f4f4f4 20%,#f0f0f0 50%,#e8e8e8 52%,#eee 100%);background-size:100% 19px;background-repeat:repeat-x;background-clip:padding-box;box-shadow:0 0 2px #fff inset,0 1px 0 rgba(0,0,0,.05);color:#333;line-height:13px;cursor:default}.chosen-container-multi .chosen-choices li.search-choice span{word-wrap:break-word}.chosen-container-multi .chosen-choices li.search-choice .search-choice-close{position:absolute;top:4px;right:3px;display:block;width:12px;height:12px;background:url(../../img/chosen-sprite.png) -42px 1px no-repeat;font-size:1px}.chosen-container-multi .chosen-choices li.search-choice .search-choice-close:hover{background-position:-42px -10px}.chosen-container-multi .chosen-choices li.search-choice-disabled{padding-right:5px;border:1px solid #ccc;background-color:#e4e4e4;background-image:linear-gradient(#f4f4f4 20%,#f0f0f0 50%,#e8e8e8 52%,#eee 100%);color:#666}.chosen-container-multi .chosen-choices li.search-choice-focus{background:#d4d4d4}.chosen-container-multi .chosen-choices li.search-choice-focus .search-choice-close{background-position:-42px -10px}.chosen-container-multi .chosen-results{margin:0;padding:0}.chosen-container-multi .chosen-drop .result-selected{display:list-item;color:#ccc;cursor:default}.chosen-container-active .chosen-single{border:1px solid #5897fb;box-shadow:0 0 5px rgba(0,0,0,.3)}.chosen-container-active.chosen-with-drop .chosen-single{border:1px solid #aaa;border-bottom-right-radius:0;border-bottom-left-radius:0;background-image:linear-gradient(#eee 20%,#fff 80%);box-shadow:0 1px 0 #fff inset}.chosen-container-active.chosen-with-drop .chosen-single div{border-left:0;background:transparent}.chosen-container-active.chosen-with-drop .chosen-single div b{background-position:-18px 2px}.chosen-container-active .chosen-choices{border:1px solid #5897fb;box-shadow:0 0 5px rgba(0,0,0,.3)}.chosen-container-active .chosen-choices li.search-field input[type=text]{color:#222!important}.chosen-disabled{opacity:.5!important;cursor:default}.chosen-disabled .chosen-single{cursor:default}.chosen-disabled .chosen-choices .search-choice .search-choice-close{cursor:default}.chosen-rtl{text-align:right}.chosen-rtl .chosen-single{overflow:visible;padding:0 8px 0 0}.chosen-rtl .chosen-single span{margin-right:0;margin-left:26px;direction:rtl}.chosen-rtl .chosen-single-with-deselect span{margin-left:38px}.chosen-rtl .chosen-single div{right:auto;left:3px}.chosen-rtl .chosen-single abbr{right:auto;left:26px}.chosen-rtl .chosen-choices li{float:right}.chosen-rtl .chosen-choices li.search-field input[type=text]{direction:rtl}.chosen-rtl .chosen-choices li.search-choice{margin:3px 5px 3px 0;padding:3px 5px 3px 19px}.chosen-rtl .chosen-choices li.search-choice .search-choice-close{right:auto;left:4px}.chosen-rtl.chosen-container-single .chosen-results{margin:0 0 4px 4px;padding:0 4px 0 0}.chosen-rtl .chosen-results li.group-option{padding-right:15px;padding-left:0}.chosen-rtl.chosen-container-active.chosen-with-drop .chosen-single div{border-right:0}.chosen-rtl .chosen-search input[type=text]{padding:4px 5px 4px 20px;background:url(../../img/chosen-sprite.png) no-repeat -30px -20px;direction:rtl}.chosen-rtl.chosen-container-single .chosen-single div b{background-position:6px 2px}.chosen-rtl.chosen-container-single.chosen-with-drop .chosen-single div b{background-position:-12px 2px}@media only screen and (-webkit-min-device-pixel-ratio:1.5),only screen and (min-resolution:144dpi),only screen and (min-resolution:1.5dppx){.chosen-rtl .chosen-search input[type=text],.chosen-container-single .chosen-single abbr,.chosen-container-single .chosen-single div b,.chosen-container-single .chosen-search input[type=text],.chosen-container-multi .chosen-choices .search-choice .search-choice-close,.chosen-container .chosen-results-scroll-down span,.chosen-container .chosen-results-scroll-up span{background-image:url(../img/chosen-sprite@2x.png)!important;background-size:52px 37px!important;background-repeat:no-repeat!important}}
